@@ -34,5 +34,8 @@ EXTENSIONS = [
 # Objects
 OBJECT_THERMOSTAT = "thermostat"
 OBJECT_COUNTER = "counter"
+OBJECT_TEMPO = "tempo"
+OBJECT_TIMER = "timer" # parent
+
+OBJECTS = [OBJECT_THERMOSTAT, OBJECT_COUNTER, OBJECT_TEMPO]
 
-OBJECTS = [OBJECT_THERMOSTAT, OBJECT_COUNTER]
