@@ -10,6 +10,12 @@ class Extension:
         self._ipx = ipx
         self._ext_type = ext_type
         self._ext_number = ext_number
+        self._name = ipx.get_obj_name(obj_type, obj_number)
         self._config = ipx.get_ext_config(ext_type, ext_number)
         self._ext_id = ipx.get_ext_id(ext_type, ext_number)
         self._io_number = io_number
+
+    @property
+    def name(self) -> str:
+        """Return the name set in the config."""
+        return self._name
