@@ -208,16 +208,20 @@ class IPX800:
         """Update the list of configured objects."""
         objects_config = []
         for type_object in OBJECTS:
+            search_object = OBJECT_TIMER if type_object in [OBJECT_TEMPO] else type_object
             try:
-                for extension in await self._request_api(
-                    f"object/{type_object}", params={"option": "filter_id"}
+                for obj in await self._request_api(
+                    f"object/{search_object}", params={"option": "filter_id"}
                 ):
+                    # ignore objects with same parent object
+                    if search_object == OBJECT_TIMER and obj["func"] != type_object:
+                        continue
                     objects_config.append(
                         {
                             API_CONFIG_TYPE: type_object,
-                            API_CONFIG_ID: extension["_id"],
-                            API_CONFIG_NAME: extension["name"],
-                            API_CONFIG_PARAMS: extension,
+                            API_CONFIG_ID: obj["_id"],
+                            API_CONFIG_NAME: obj["name"],
+                            API_CONFIG_PARAMS: obj,
                         }
                     )
             except IPX800RequestError:
@@ -238,6 +242,12 @@ class IPX800:
             x for x in self.extensions_config if x[API_CONFIG_TYPE] == ext_type
         ]
         return extensions[ext_number - 1][API_CONFIG_ID]
+    def get_ext_name(self, ext_type: str, ext_number: int) -> int:
+        """Return the name set in the IPX config."""
+        extensions = [
+            x for x in self.extensions_config if x[API_CONFIG_TYPE] == ext_type
+        ]
+        return extensions[ext_number - 1][API_CONFIG_NAME]
 
     async def get_ext_states(self, ext_type: str, ext_id: int) -> dict:
         """Return all values of extension."""
@@ -253,6 +263,11 @@ class IPX800:
         objs = [x for x in self.objects_config if x[API_CONFIG_TYPE] == obj_type]
         return objs[obj_number - 1][API_CONFIG_ID]
 
+    def get_obj_name(self, obj_type: str, obj_number: int) -> str:
+        """Return the name set in the IPX config."""
+        objs = [x for x in self.objects_config if x[API_CONFIG_TYPE] == obj_type]
+        return objs[obj_number - 1][API_CONFIG_NAME]
+
     # Get/Update commands
 
     async def get_io(self, id: int) -> bool:
